﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;

// Számológép program, amely támogatja a négy alapműveltet valós számokkal
namespace ELTE.Forms.Calculator
{
    // a lehetséges műveleteket egy felsoroló típusban tároljuk
    public enum Operation { None, Add, Substract, Multiply, Divide }

    public partial class CalculatorForm : Form
    {
        private Double _FistNumber, _SecondNumber; // eltároljuk az operandusokat
        private Operation _LastOperation; // eltároljuk a legutoljára használt műveletet

        public CalculatorForm()
        {
            InitializeComponent();
            _LastOperation = Operation.None; // kezdetben nincs művelet
            _FistNumber = _SecondNumber = 0;
            _TextNumber.Text = "0";
        }

        // egy közös eseménykezelő az összes gombnak
        private void Button_Click(object sender, EventArgs e)
        {
            try
            {
                if (_LastOperation != Operation.None) // ha máűr volt művelet
                {
                    _SecondNumber = Double.Parse(_TextNumber.Text); // beolvassuk a második operandust
                    switch (_LastOperation) // végrehajtjuk a korábbi műveletet a két operandussal
                    {
                        case Operation.Add: Add(); break;
                        case Operation.Substract: Substract(); break;
                        case Operation.Multiply: Multiply(); break;
                        case Operation.Divide: Divide(); break;
                    }
                }
                // minden esetben:
                _FistNumber = Double.Parse(_TextNumber.Text); // eltároljuk az első operandust
                switch (((Button)sender).Text)
                // megvizsgáljuk, milyen az eseményt kiváltó gomb felirata, így eldönthetjük, melyik gombot nyomták le
                {
                    case "+": _LastOperation = Operation.Add; break;
                    case "-": _LastOperation = Operation.Substract; break;
                    case "*": _LastOperation = Operation.Multiply; break;
                    case "/": _LastOperation = Operation.Divide; break;
                    case "=": _LastOperation = Operation.None; break; // beállítjuk a megfelelő műveletet
                }
            }
            catch (OverflowException)
            {
                MessageBox.Show("Your input has to many digits!", "Calculation Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
            catch (FormatException)
            {
                MessageBox.Show("Your input is not a real number!\nPlease correct!", "Calculation Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
            catch (NullReferenceException)
            {
                MessageBox.Show("No number in input!\nPlease correct!", "Calculation Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
            finally
            {
                _TextNumber.Focus(); // visszaadjuk a vezérlést a szövegdoboznak
            }
        }

        // megfelelő művelet végrehajtása
        private void Add()
        {
            Double result = _FistNumber + _SecondNumber; // művelet
            _ListHistory.Items.Add(_FistNumber.ToString() + "+" + _SecondNumber.ToString() + "=" + result.ToString()); // művelet kiírása a listába
            _TextNumber.Text = result.ToString(); // eredmény kiírása a felső sávba
        }
        private void Substract()
        {
            Double result = _FistNumber - _SecondNumber;
            _ListHistory.Items.Add(_FistNumber.ToString() + "-" + _SecondNumber.ToString() + "=" + result.ToString());
            _TextNumber.Text = result.ToString();
        }
        private void Multiply()
        {
            Double result = _FistNumber * _SecondNumber;
            _ListHistory.Items.Add(_FistNumber.ToString() + "*" + _SecondNumber.ToString() + "=" + result.ToString());
            _TextNumber.Text = result.ToString();
        }
        private void Divide()
        {
            Double result = _FistNumber / _SecondNumber;
            _ListHistory.Items.Add(_FistNumber.ToString() + "/" + _SecondNumber.ToString() + "=" + result.ToString());
            _TextNumber.Text = result.ToString();
        }
    }
}
